package tamanegisoul.ar;

import java.math.BigDecimal;
import java.math.RoundingMode;

import android.content.Context;
import android.util.Log;
import android.view.View;
import android.view.inputmethod.InputMethodManager;

import com.google.android.maps.GeoPoint;

/**
 * ユーティリティクラス。
 * 
 * @author TamanegiSoul
 */
public final class Utils {

	/**
	 * GeoPointオブジェクトを生成する。
	 * @param longitude 経度
	 * @param latitude 緯度
	 * @return GeoPointオブジェクト
	 */
	public static GeoPoint toGeoPoint(double longitude, double latitude) {
		BigDecimal lngDecimal = new BigDecimal(String.valueOf(longitude));
		BigDecimal latDecimal = new BigDecimal(String.valueOf(latitude));
		// 小数点第6位まで四捨五入
		latDecimal = latDecimal.setScale(6, RoundingMode.HALF_UP);
		lngDecimal = lngDecimal.setScale(6, RoundingMode.HALF_UP);
		latDecimal = latDecimal.multiply(BigDecimal.valueOf(1E6));
		lngDecimal = lngDecimal.multiply(BigDecimal.valueOf(1E6));

		GeoPoint point = new GeoPoint(latDecimal.intValue(), lngDecimal.intValue());
		return point;
	}

	/**
	 * キーボードを隠す。
	 * @param view Viewオブジェクト
	 */
	public static void hideKeyboard(View view) {
		InputMethodManager inputMethodManager = (InputMethodManager) view.getContext().getSystemService(Context.INPUT_METHOD_SERVICE);
		inputMethodManager.hideSoftInputFromWindow(view.getWindowToken(), 0);
	}

	/**
	 * デバッグログを出力する。<br/>
	 * clsのクラス名とmessagesをつないだ文字列をログとして出力する。
	 * @param cls クラス名
	 * @param messages メッセージ
	 */
	public static void logDebug(Class<?> cls, String... messages) {
		StringBuilder messageBuilder = new StringBuilder(cls.getCanonicalName()).append(" ");
		for (String message : messages) {
			messageBuilder.append(message);
		}
		Log.d("AtReminder", messageBuilder.toString());
	}

	/**
	 * エラーログを出力する。<br/>
	 * clsのクラス名とmessagesをつないだ文字列をログとして出力する。
	 * @param cls クラス名
	 * @param th 例外
	 * @param messages メッセージ
	 */
	public static void logError(Class<?> cls, Throwable th, String... messages) {
		StringBuilder messageBuilder = new StringBuilder(cls.getCanonicalName()).append(" ");
		for (String message : messages) {
			messageBuilder.append(message);
		}
		Log.e("AtReminder", messageBuilder.toString(), th);
	}
}
