package tamanegisoul.ar.action;

import java.io.IOException;
import java.util.List;
import java.util.Locale;

import tamanegisoul.ar.R;
import tamanegisoul.ar.Utils;
import tamanegisoul.ar.db.DBHelper;
import tamanegisoul.ar.widget.ClearButtonOnClickListener;
import tamanegisoul.ar.widget.PinItemizedOverlay;
import tamanegisoul.ar.widget.ReturnButtonClickListener;
import android.app.Dialog;
import android.content.ContentValues;
import android.content.DialogInterface;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.location.Address;
import android.location.Geocoder;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.Toast;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapActivity;
import com.google.android.maps.MapView;
import com.google.android.maps.Overlay;

/**
 * 地点登録画面。
 * @author TamanegiSoul
 */
public class LocationSettingActivity extends MapActivity {

	private LocationSettingActivity mInstance;
	private String mCurrentSettingId;
	private GeoPoint mTappedPoint;
	private PinItemizedOverlay mPinItemizedOverlay;
	private Dialog mSettingDialog;
	private EditText mCurrentSettingName;
	private Geocoder mGeocoder;
	private MapView mMapView;
	private SQLiteDatabase mDatabase;

	private class LocationOverlay extends Overlay {
		@Override
		public boolean onTap(GeoPoint p, MapView mapView) {
			Utils.logDebug(this.getClass(), "onTap");
			mTappedPoint = p;
			// dialogの閉じる処理でfinish()すると例外が起きるのでdismissでfinish
			mSettingDialog.setOnDismissListener(new Dialog.OnDismissListener() {
				public void onDismiss(DialogInterface arg0) {
					finish();
				}
			});
			mSettingDialog.show();
			return true;
		}
	}

	@Override
	protected void onCreate(Bundle icicle) {
		Utils.logDebug(this.getClass(), "onCreate");
		super.onCreate(icicle);

		mInstance = this;
		mDatabase = DBHelper.getDatabase(this);
		mGeocoder = new Geocoder(this, Locale.JAPAN);

		setContentView(R.layout.location_setting);

		// マップ
		mMapView = (MapView) findViewById(R.id.location_setting_map);
		mMapView.setBuiltInZoomControls(true);
		mMapView.getController().setZoom(17);
		mMapView.getOverlays().add(new LocationOverlay());
		mPinItemizedOverlay = new PinItemizedOverlay(getResources().getDrawable(R.drawable.pin));
		mMapView.getOverlays().add(mPinItemizedOverlay);

		// 検索ボタン
		ImageButton searchButton = (ImageButton) findViewById(R.id.location_setting_search);
		final EditText searchText = (EditText) findViewById(R.id.location_setting_search_text);
		searchButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View arg0) {
				if (searchText.getText().length() > 0) {
					try {
						List<Address> addressList = mGeocoder.getFromLocationName(searchText.getText().toString(), 1);
						if (addressList != null && addressList.size() > 0) {
							Address address = addressList.get(0);
							GeoPoint point = Utils.toGeoPoint(address.getLongitude(), address.getLatitude());
							mMapView.getController().setCenter(point);
							Utils.hideKeyboard(arg0);
							// 地点新規追加の場合、地点名に検索文字列を設定
							if (mCurrentSettingName.getText().length() == 0)
								mCurrentSettingName.setText(searchText.getText());
						} else {
							Toast.makeText(mInstance, R.string.not_found, Toast.LENGTH_LONG).show();
						}
					} catch (IOException e) {
						Utils.logError(this.getClass(), e);
					}
				}
			}
		});

		// 検索clearボタン
		ImageButton clearButton = (ImageButton) findViewById(R.id.location_setting_input_clear);
		clearButton.setOnClickListener(new ClearButtonOnClickListener(searchText));

		// 設定ダイアログ
		mSettingDialog = new Dialog(this);
		mSettingDialog.setContentView(R.layout.location_setting_dialog);
		mSettingDialog.setTitle(R.string.location_setting);
		mCurrentSettingName = (EditText) mSettingDialog.findViewById(R.id.location_setting_dialog_name);
		// 設定ボタン
		ImageButton set = (ImageButton) mSettingDialog.findViewById(R.id.location_setting_dialog_set);
		set.setOnClickListener(new View.OnClickListener() {
			public void onClick(View view) {
				if (mCurrentSettingName.getText().length() > 0) {
					ContentValues v = new ContentValues();
					v.put(DBHelper.TABLE_LOCATION_COLUMN_NAME, mCurrentSettingName.getText().toString());
					v.put(DBHelper.TABLE_LOCATION_COLUMN_LATITUDE, mTappedPoint.getLatitudeE6());
					v.put(DBHelper.TABLE_LOCATION_COLUMN_LONGITUDE, mTappedPoint.getLongitudeE6());
					if (mCurrentSettingId == null) {
						mDatabase.insert(DBHelper.TABLE_LOCATION, null, v);
					} else {
						mDatabase.update(DBHelper.TABLE_LOCATION, v, DBHelper.TABLE_LOCATION_COLUMN_ID + "=?", new String[] { mCurrentSettingId });
					}
					DBHelper.notifyDataChanged(DBHelper.TABLE_LOCATION);
					mSettingDialog.dismiss();
				}
			}
		});
		// クリアボタン
		final EditText nameText = (EditText) mSettingDialog.findViewById(R.id.location_setting_dialog_name);
		ImageButton clear = (ImageButton) mSettingDialog.findViewById(R.id.location_setting_dialog_clear);
		clear.setOnClickListener(new ClearButtonOnClickListener(nameText));
		// キャンセルボタン
		ImageButton cancel = (ImageButton) mSettingDialog.findViewById(R.id.location_setting_dialog_cancel);
		cancel.setOnClickListener(new View.OnClickListener() {
			public void onClick(View arg0) {
				mSettingDialog.hide();
			}
		});
		// 戻るボタン
		ImageButton returnButton = (ImageButton) mSettingDialog.findViewById(R.id.location_setting_dialog_return);
		returnButton.setOnClickListener(new ReturnButtonClickListener());

		// 追加と変更で処理分岐
		mCurrentSettingId = getIntent().getStringExtra(DBHelper.TABLE_LOCATION_COLUMN_ID);
		Utils.logDebug(this.getClass(), "currentSettingId:", mCurrentSettingId);
		GeoPoint currentPoint = null;
		if (mCurrentSettingId == null) {
			// 新規追加
			mCurrentSettingName.setText("");
			currentPoint = new GeoPoint(35713730, 139762337);
			mPinItemizedOverlay.clearPoint();
		} else {
			// 変更
			Cursor c = mDatabase.query(DBHelper.TABLE_LOCATION, new String[] { DBHelper.TABLE_LOCATION_COLUMN_NAME,
					DBHelper.TABLE_LOCATION_COLUMN_LATITUDE, DBHelper.TABLE_LOCATION_COLUMN_LONGITUDE }, DBHelper.TABLE_LOCATION_COLUMN_ID + "=?",
					new String[] { mCurrentSettingId }, null, null, null);
			c.moveToFirst();
			mCurrentSettingName.setText(c.getString(0));
			currentPoint = new GeoPoint(c.getInt(1), c.getInt(2));
			mPinItemizedOverlay.addPoint(currentPoint);
			c.close();
		}
		mMapView.getController().setCenter(currentPoint);
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		mDatabase.close();
	}

	@Override
	protected boolean isRouteDisplayed() {
		return false;
	}

}
