package tamanegisoul.ar.action;

import java.util.List;

import tamanegisoul.ar.R;
import tamanegisoul.ar.Utils;
import tamanegisoul.ar.db.DBHelper;
import tamanegisoul.ar.widget.NotifedTodoListAdapter;
import tamanegisoul.ar.widget.StartActivityActionListener;
import android.app.Activity;
import android.app.ActivityManager;
import android.app.ActivityManager.RunningServiceInfo;
import android.content.Intent;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.widget.CompoundButton;
import android.widget.ImageButton;
import android.widget.ListView;
import android.widget.ToggleButton;

/**
 * メインページ
 * @author TamanegiSoul
 */
public class MainActivity extends Activity {

	private MainActivity mInstance;
	private SQLiteDatabase mDatabase;
	private Cursor mTodoCursor;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		Utils.logDebug(MainActivity.class, "onCreate");
		super.onCreate(savedInstanceState);

		mInstance = this;
		mDatabase = DBHelper.getDatabase(mInstance);

		setContentView(R.layout.main);

		// TODOリスト
		ListView todoListView = (ListView) findViewById(R.id.main_todo_list);
		mTodoCursor = mDatabase.query(DBHelper.TABLE_TODO, null, DBHelper.TABLE_TODO_COLUMN_NOTIFIED + "=1", null, null, null, null);
		todoListView.setAdapter(new NotifedTodoListAdapter(this, mTodoCursor));

		// GPSサービススイッチ
		ToggleButton serviceSwitchButton = (ToggleButton) findViewById(R.id.main_service_switch);
		serviceSwitchButton.setChecked(isServiceRunning());
		serviceSwitchButton.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
			private Intent intent = new Intent(mInstance, LocationPollingService.class);

			public void onCheckedChanged(CompoundButton button, boolean checked) {
				Utils.logDebug(MainActivity.class, "ServiceSwitch changed:", String.valueOf(checked));
				if (checked) {
					startService(intent);
				} else {
					stopService(intent);
				}
			}
		});

		// 地点一覧ボタン
		ImageButton locationListButton = (ImageButton) findViewById(R.id.main_location);
		locationListButton.setOnClickListener(new StartActivityActionListener(this, new Intent(mInstance, LocationListActivity.class)));

		// 設定ボタン
		ImageButton settingsButton = (ImageButton) findViewById(R.id.main_settings);
		settingsButton.setOnClickListener(new StartActivityActionListener(this, new Intent(mInstance, SettingsActivity.class)));
	}

	@Override
	protected void onDestroy() {
		Utils.logDebug(MainActivity.class, "onDestroy");
		super.onDestroy();
		mDatabase.close();
		mTodoCursor.close();
	}

	/**
	 * {@link LocationPollingService}が開始されているかどうかを調べる
	 * @return 開始されている場合はtrue
	 */
	private boolean isServiceRunning() {
		ActivityManager am = (ActivityManager) this.getSystemService(ACTIVITY_SERVICE);
		List<ActivityManager.RunningServiceInfo> services = am.getRunningServices(Integer.MAX_VALUE);
		for (int i = 0; i < services.size(); i++) {
			RunningServiceInfo serviceInfo = services.get(i);
			if (serviceInfo.service.getClassName().equals(LocationPollingService.class.getCanonicalName()) && serviceInfo.started) {
				return true;
			}
		}
		return false;
	}

}