package tamanegisoul.ar.action;

import java.util.Arrays;
import java.util.List;

import tamanegisoul.ar.R;
import tamanegisoul.ar.Utils;
import tamanegisoul.ar.db.DBHelper;
import tamanegisoul.ar.widget.ReturnButtonClickListener;
import android.app.Activity;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ImageButton;
import android.widget.Spinner;

/**
 * 設定画面
 * @author TamanegiSoul
 */
public class SettingsActivity extends Activity {

	private static List<String> sTimes = Arrays.asList(new String[] { "0", "30", "60" });
	private static List<String> sDistances = Arrays.asList(new String[] { "0", "100", "500" });
	private static List<String> sNotifyDistances = Arrays.asList(new String[] { "0", "100", "500" });
	
	private static class PollingItemSelectedListener implements AdapterView.OnItemSelectedListener {
		private SQLiteDatabase mDatabase;
		private String mKey;
		private List<String> mValues;
		public PollingItemSelectedListener(SQLiteDatabase db, String key, List<String> values) {
			super();
			this.mDatabase = db;
			this.mKey = key;
			this.mValues = values;
		}
		public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
			ContentValues cv = new ContentValues();
			cv.put(DBHelper.TABLE_SETTINGS_COLUMN_NAME, mKey);
			cv.put(DBHelper.TABLE_SETTINGS_COLUMN_VALUE, mValues.get(position));
			mDatabase.update(DBHelper.TABLE_SETTINGS, cv, DBHelper.TABLE_SETTINGS_COLUMN_NAME + "=?",
					new String[] { mKey });
			Utils.logDebug(SettingsActivity.class, mKey, " saved:", mValues.get(position));
			DBHelper.notifyDataChanged(DBHelper.TABLE_SETTINGS);
		}
		public void onNothingSelected(AdapterView<?> arg0) {
		}
	}

	private SQLiteDatabase mDatabase;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.settings);

		mDatabase = DBHelper.getDatabase(this);

		// ポーリング間隔時間
		Spinner timeSpinner = (Spinner) findViewById(R.id.settings_gps_polling_interval_time);
		timeSpinner.setAdapter(new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, sTimes));
		Cursor timeCursor = mDatabase.query(DBHelper.TABLE_SETTINGS, null, DBHelper.TABLE_SETTINGS_COLUMN_NAME + "=?",
				new String[] { DBHelper.TABLE_SETTINGS_COLUMN_NAME_POLLING_TIME }, null, null, null);
		timeCursor.moveToFirst();
		String savedTime = timeCursor.getString(2);
		timeCursor.close();
		timeSpinner.setSelection(sTimes.indexOf(savedTime));
		timeSpinner.setOnItemSelectedListener(new PollingItemSelectedListener(mDatabase, DBHelper.TABLE_SETTINGS_COLUMN_NAME_POLLING_TIME, sTimes));
		// ポーリング間隔距離
		Spinner distanceSpinner = (Spinner) findViewById(R.id.settings_gps_polling_interval_distance);
		distanceSpinner.setAdapter(new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, sDistances));
		Cursor distanceCursor = mDatabase.query(DBHelper.TABLE_SETTINGS, null, DBHelper.TABLE_SETTINGS_COLUMN_NAME + "=?",
				new String[] { DBHelper.TABLE_SETTINGS_COLUMN_NAME_POLLING_DISTANCE }, null, null, null);
		distanceCursor.moveToFirst();
		String savedDistance = distanceCursor.getString(2);
		distanceCursor.close();
		distanceSpinner.setSelection(sDistances.indexOf(savedDistance));
		distanceSpinner.setOnItemSelectedListener(new PollingItemSelectedListener(mDatabase, DBHelper.TABLE_SETTINGS_COLUMN_NAME_POLLING_DISTANCE, sDistances));
		// 通知距離
		Spinner notifyDistanceSpinner = (Spinner) findViewById(R.id.layout_settings_notify_distance_spiiner);
		notifyDistanceSpinner.setAdapter(new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, sNotifyDistances));
		Cursor notifyDistanceCursor = mDatabase.query(DBHelper.TABLE_SETTINGS, null, DBHelper.TABLE_SETTINGS_COLUMN_NAME + "=?",
				new String[] { DBHelper.TABLE_SETTINGS_COLUMN_NAME_NOTIFY_DISTANCE }, null, null, null);
		notifyDistanceCursor.moveToFirst();
		String savedNotifyDistance = notifyDistanceCursor.getString(2);
		notifyDistanceCursor.close();
		notifyDistanceSpinner.setSelection(sDistances.indexOf(savedNotifyDistance));
		notifyDistanceSpinner.setOnItemSelectedListener(new PollingItemSelectedListener(mDatabase, DBHelper.TABLE_SETTINGS_COLUMN_NAME_NOTIFY_DISTANCE, sNotifyDistances));
		// 戻るボタン
		ImageButton homeButton = (ImageButton)findViewById(R.id.settings_home_button);
		homeButton.setOnClickListener(new ReturnButtonClickListener());
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		mDatabase.close();
	}

}
