package tamanegisoul.ar.action;

import tamanegisoul.ar.R;
import tamanegisoul.ar.Utils;
import tamanegisoul.ar.db.DBHelper;
import tamanegisoul.ar.widget.ClearButtonOnClickListener;
import tamanegisoul.ar.widget.ReturnButtonClickListener;
import tamanegisoul.ar.widget.SensitiveCursorAdapter;
import tamanegisoul.ar.widget.TodoListAdapter;
import android.app.Activity;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.ListView;

/**
 * TODO一覧画面
 * @author TamanegiSoul
 */
public class TodoListActivity extends Activity {

	private TodoListActivity mInstance;
	private String mLocationId;
	private SQLiteDatabase mDatabase;
	private SensitiveCursorAdapter mCursorAdapter;
	private Cursor mCursor;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		Utils.logDebug(this.getClass(), "onCreate");
		super.onCreate(savedInstanceState);

		mInstance = this;
		mDatabase = DBHelper.getDatabase(this);
		mLocationId = getIntent().getStringExtra(DBHelper.TABLE_TODO_COLUMN_LOCATION_ID);

		setContentView(R.layout.todo_list);

		// TODO一覧
		mCursor = mDatabase.query(DBHelper.TABLE_TODO, null, DBHelper.TABLE_TODO_COLUMN_LOCATION_ID + "=?", new String[] { mLocationId }, null, null, null);
		mCursorAdapter = new TodoListAdapter(this, mCursor);
		ListView list = (ListView) findViewById(R.id.todo_list_list);
		list.setAdapter(mCursorAdapter);

		// 追加ボタン
		ImageButton addButton = (ImageButton) findViewById(R.id.todo_list_add);
		addButton.setOnClickListener(new View.OnClickListener() {
			public void onClick(View view) {
				EditText text = (EditText) mInstance.findViewById(R.id.todo_list_name);
				String name = text.getText().toString();
				if (name.length() != 0) {
					ContentValues values = new ContentValues();
					values.put(DBHelper.TABLE_TODO_COLUMN_LOCATION_ID, mLocationId);
					values.put(DBHelper.TABLE_TODO_COLUMN_NAME, text.getText().toString());
					values.put(DBHelper.TABLE_TODO_COLUMN_NOTIFIED, 0);
					mDatabase.insert(DBHelper.TABLE_TODO, null, values);
					DBHelper.notifyDataChanged(DBHelper.TABLE_TODO);
				}
				Utils.hideKeyboard(view);
			}
		});

		// クリアボタン
		ImageButton clearButton = (ImageButton) findViewById(R.id.todo_list_clear);
		clearButton.setOnClickListener(new ClearButtonOnClickListener((EditText) mInstance.findViewById(R.id.todo_list_name)));

		// 戻るボタン
		ImageButton returnButton = (ImageButton) findViewById(R.id.todo_list_return);
		returnButton.setOnClickListener(new ReturnButtonClickListener());
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		mCursorAdapter.destroy();
		mCursor.close();
		mDatabase.close();
	}

}
