package tamanegisoul.ar.db;

import java.util.HashSet;
import java.util.Set;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

/**
 * DBヘルパークラス
 * @author TamanegiSoul
 */
public class DBHelper extends SQLiteOpenHelper {
	
	private static final String DB_NAME = "AtReminder";
	public static final String TABLE_LOCATION = "location";
	public static final String TABLE_LOCATION_COLUMN_ID = "_id";
	public static final String TABLE_LOCATION_COLUMN_NAME = "name";
	public static final String TABLE_LOCATION_COLUMN_LATITUDE = "latitude";
	public static final String TABLE_LOCATION_COLUMN_LONGITUDE = "longitude";
	public static final String TABLE_TODO = "todo";
	public static final int TABLE_TODO_COLUMN_IDX_ID = 0;
	public static final int TABLE_TODO_COLUMN_IDX_LOCATION_ID = 1;
	public static final int TABLE_TODO_COLUMN_IDX_NAME = 2;
	public static final int TABLE_TODO_COLUMN_IDX_NOTIFIED = 3;
	public static final String TABLE_TODO_COLUMN_ID = "_id";
	public static final String TABLE_TODO_COLUMN_LOCATION_ID = "location_id";
	public static final String TABLE_TODO_COLUMN_NAME = "name";
	public static final String TABLE_TODO_COLUMN_NOTIFIED = "notified";
	public static final String TABLE_SETTINGS = "settings";
	public static final String TABLE_SETTINGS_COLUMN_NAME = "name";
	public static final String TABLE_SETTINGS_COLUMN_VALUE= "value";
	public static final String TABLE_SETTINGS_COLUMN_NAME_POLLING_TIME = "polling_time";
	public static final String TABLE_SETTINGS_COLUMN_NAME_POLLING_DISTANCE= "polling_distance";
	public static final String TABLE_SETTINGS_COLUMN_NAME_NOTIFY_DISTANCE= "notify_distance";
	
	private static Set<DataChangeListener> sListeners = new HashSet<DataChangeListener>();
	
	public static boolean registerDataChangeListener(DataChangeListener listener) {
		return sListeners.add(listener);
	}
	
	public static boolean unregisterDataChangeListener(DataChangeListener listener) {
		return sListeners.remove(listener);
	}
	
	public static void notifyDataChanged(String tableName) {
		for(DataChangeListener listener : sListeners) {
			listener.onDataChanged(tableName);
		}
	}
	
	public static SQLiteDatabase getDatabase(Context context) {
		return new DBHelper(context).getWritableDatabase();
	}

	private DBHelper(Context context) {
		super(context, DB_NAME, null, 1);
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		Cursor c = db.rawQuery("select count(*) from sqlite_master where type='table' and name=?", new String[]{TABLE_LOCATION});
		c.moveToFirst();
		if(c.getInt(0) == 0){
			db.execSQL("create table location(_id integer primary key autoincrement, name text, latitude integer, longitude integer);");
			db.execSQL("create table todo(_id integer primary key autoincrement, location_id integer, name text, notified int);");
			db.execSQL("create table settings(_id integer primary key autoincrement, name text, value text);");
			ContentValues values = new ContentValues();
			values.put(DBHelper.TABLE_SETTINGS_COLUMN_NAME, TABLE_SETTINGS_COLUMN_NAME_POLLING_DISTANCE);
			values.put(DBHelper.TABLE_SETTINGS_COLUMN_VALUE, "100");
			db.insert(DBHelper.TABLE_SETTINGS, null, values);
			values.clear();
			values.put(DBHelper.TABLE_SETTINGS_COLUMN_NAME, TABLE_SETTINGS_COLUMN_NAME_POLLING_TIME);
			values.put(DBHelper.TABLE_SETTINGS_COLUMN_VALUE, "30");
			db.insert(DBHelper.TABLE_SETTINGS, null, values);
			values.clear();
			values.put(DBHelper.TABLE_SETTINGS_COLUMN_NAME, TABLE_SETTINGS_COLUMN_NAME_NOTIFY_DISTANCE);
			values.put(DBHelper.TABLE_SETTINGS_COLUMN_VALUE, "100");
			db.insert(DBHelper.TABLE_SETTINGS, null, values);
		}
	}

	@Override
	public void onUpgrade(SQLiteDatabase arg0, int arg1, int arg2) {
	}
}
